<?php
namespace BooklyMollie\Lib\Payment;

use Bookly\Lib as BooklyLib;
use BooklyMollie\Lib;

/**
 * Class Mollie
 */
class Mollie
{
    // Array for cleaning Mollie request
    public static $remove_parameters = array( 'bookly_action', 'bookly_fid', 'error_msg' );

    /**
     * Handles webhook messages
     */
    public static function webhook()
    {
        try {
            self::handlePayment( self::getPayment( $_REQUEST['id'] ) );
        } catch ( \Exception $e ) { }
    }

    /**
     * Check gateway data and if ok save payment info
     *
     * @param Api $details
     */
    public static function handlePayment( Api $details )
    {
        $payment = new BooklyLib\Entities\Payment();
        $loaded  = $payment->loadBy( array(
            'type' => BooklyLib\Entities\Payment::TYPE_MOLLIE,
            'id'   => $details->metadata->payment_id,
        ) );
        if ( $loaded ) {
            if ( $details->isPaid() ) {
                // Handle completed card & bank transfers here
                $total    = (float) $payment->getPaid();
                $received = (float) $details->amount->value;

                if ( $payment->getStatus() == BooklyLib\Entities\Payment::STATUS_COMPLETED
                    || abs( $received - $total ) > 0.01
                    || $details->amount->currency != BooklyLib\Config::getCurrency()
                ) {
                    wp_send_json_success();
                } else {
                    $payment->setStatus( BooklyLib\Entities\Payment::STATUS_COMPLETED )->save();
                    if ( $order = BooklyLib\DataHolders\Booking\Order::createFromPayment( $payment ) ) {
                        current( $order->getItems() )->getCA()->setJustCreated( true );
                        BooklyLib\Notifications\Cart\Sender::send( $order );
                    }
                    foreach (
                        BooklyLib\Entities\Appointment::query( 'a' )
                            ->leftJoin( 'CustomerAppointment', 'ca', 'a.id = ca.appointment_id' )
                            ->where( 'ca.payment_id', $payment->getId() )->find() as $appointment
                    ) {
                        BooklyLib\Proxy\Pro::syncGoogleCalendarEvent( $appointment );
                        BooklyLib\Proxy\OutlookCalendar::syncEvent( $appointment );
                    }
                }
            } elseif ( ! $details->isOpen() && ! $details->isPending() ) {
                /** @var BooklyLib\Entities\CustomerAppointment $ca */
                foreach ( BooklyLib\Entities\CustomerAppointment::query()->where( 'payment_id', $payment->getId() )->find() as $ca ) {
                    BooklyLib\Utils\Log::deleteEntity( $ca, __METHOD__ );
                    $ca->deleteCascade();
                }
                $payment->delete();
            }
        }
        wp_send_json_success();
    }

    /**
     * Redirect to Mollie Payment page, or step payment.
     *
     * @param $form_id
     * @param BooklyLib\UserBookingData $userData
     * @param string $page_url
     */
    public static function paymentPage( $form_id, BooklyLib\UserBookingData $userData, $page_url )
    {
        $cart_info = $userData->cart->getInfo( BooklyLib\Entities\Payment::TYPE_MOLLIE );

        $coupon  = $userData->getCoupon();
        $payment = new BooklyLib\Entities\Payment();
        $payment->setType( BooklyLib\Entities\Payment::TYPE_MOLLIE )
            ->setStatus( BooklyLib\Entities\Payment::STATUS_PENDING )
            ->setCartInfo( $cart_info )
            ->save();
        $order = $userData->save( $payment );
        try {
            $mollie_payment = new Api( get_option( 'bookly_mollie_api_key' ) );
            $mollie_payment->createPayment( array(
                'amount' => array(
                    'currency' => get_option( 'bookly_pmt_currency' ),
                    'value' => $cart_info->getGatewayAmount()
                ),
                'description' => $userData->cart->getItemsTitle( 125 ),
                'redirectUrl' => add_query_arg( array( 'bookly_action' => 'mollie-response', 'bookly_fid' => $form_id ), $page_url ),
                'webhookUrl'  => add_query_arg( array( 'bookly_action' => 'mollie-webhook' ), $page_url ),
                'metadata'    => array( 'payment_id' => $payment->getId() ),
                'issuer'      => null
            ) );
            if ( $mollie_payment->isOpen() ) {
                if ( $coupon ) {
                    $coupon->claim();
                    $coupon->save();
                }
                $payment->setDetailsFromOrder( $order, $cart_info )->save();
                $userData->setPaymentStatus( BooklyLib\Entities\Payment::TYPE_MOLLIE, 'pending', $mollie_payment->id );
                $userData->sessionSave();

                header( 'Location: ' . $mollie_payment->getCheckoutUrl() );
                exit;
            } else {
                $userData->setFailedPaymentStatus( BooklyLib\Entities\Payment::TYPE_MOLLIE, 'error', __( 'Mollie error.', 'bookly' ) )
                    ->sessionSave();

                @wp_redirect( $page_url );
                exit;
            }
        } catch ( \Exception $e ) {
            $userData->setFailedPaymentStatus( BooklyLib\Entities\Payment::TYPE_MOLLIE, 'error', $e->getMessage() )
                ->sessionSave();

            @wp_redirect( $page_url );
            exit;
        }
    }

    /**
     * @param string $tr_id
     * @return Api
     * @throws \Exception
     */
    public static function getPayment( $tr_id )
    {
        $mollie_payment = new Api( get_option( 'bookly_mollie_api_key' ) );

        return $mollie_payment->getPayment( $tr_id );
    }
}