<?php
namespace BooklyMultisite\Modules\Network;

use BooklyMultisite\Lib;

class Controller
{
    const page_slug = 'bookly-multisite-network';

    public function index()
    {
        wp_enqueue_style( 'bookly-multisite-bootstrap', plugins_url() . '/bookly-addon-multisite/resources/bootstrap/css/bootstrap.min.css' );
        if ( isset( $_REQUEST['action'] ) && $_REQUEST['action'] == 'show' ) {
            $this->show();
        } else {
            $this->_index();
        }
    }

    public function _index()
    {
        $wp_list_table = _get_list_table( 'WP_MS_Sites_List_Table' );
        $wp_list_table->prepare_items();

        $this->registerBlogAddons();
        $bookly_plugins = apply_filters( 'bookly_plugins', array() );

        $this->render( 'index', compact( 'bookly_plugins', 'wp_list_table' ) );
    }

    /**
     * Register Add-ons hooks for some blog.
     *
     * @param int|null $blog_id
     */
    private function registerBlogAddons( $blog_id = null )
    {
        $bookly_plugins = apply_filters( 'bookly_plugins', array() );

        $plugins_dir = dirname( dirname( Lib\Plugin::getMainFile() ) ) . '/';
        foreach ( array( 'bookly-responsive-appointment-booking-tool', 'bookly-addon-pro' ) as $slug ) {
            if ( ! array_key_exists( $slug, $bookly_plugins ) ) {
                $loader = $plugins_dir . $slug . '/autoload.php';
                if ( is_readable( $loader ) ) {
                    include_once $loader;
                }
            }
        }

        if ( method_exists( '\BooklyPro\Lib\Base\Plugin', 'registerHooks' ) ) {
            $blog_plugins = (array) apply_filters( 'active_plugins', get_blog_option( $blog_id, 'active_plugins' ) );
            // Find all Bookly Add-ons
            foreach ( glob( $plugins_dir . 'bookly-addon-*', GLOB_ONLYDIR ) as $path ) {
                $slug = wp_basename( $path );
                if ( in_array( $slug . '/main.php', $blog_plugins ) && ! array_key_exists( $slug, $bookly_plugins ) ) {
                    include_once $path . '/autoload.php';

                    $namespace    = implode( '', array_map( 'ucfirst', explode( '-', str_replace( '-addon-', '-', basename( $path ) ) ) ) );
                    $plugin_class = '\\' . $namespace . '\Lib\Plugin';
                    \BooklyPro\Lib\Base\Plugin::registerHooks( $plugin_class );
                }
            }
        }
    }

    public function show()
    {
        // Register hooks for inactive Add-ons.
        $this->registerBlogAddons( $_REQUEST['blog_id'] );
        $errors = array();
        if ( isset ( $_POST['purchase_code'] ) ) {
            $blog_id = $_POST['blog_id'];
            $errors  = apply_filters( 'bookly_save_purchase_codes', array(), $_POST['purchase_code'], $blog_id );
        } else {
            $blog_id = $_GET['blog_id'];
        }
        $data = array(
            'blog_id' => $blog_id,
            'url'     => get_home_url( $blog_id ),
            'errors'  => implode( '<br>', $errors ),
        );

        $this->render( 'show', $data );
    }

    /**
     * Render a template file.
     *
     * @param $template
     * @param array $variables
     * @param bool $echo
     * @return string
     * @throws \Exception
     */
    protected function render( $template, $variables = array(), $echo = true )
    {
        extract( $variables );

        // Start output buffering.
        ob_start();
        ob_implicit_flush( 0 );

        try {
            include __DIR__ . '/templates/' . $template . '.php';
        } catch ( \Exception $e ) {
            ob_end_clean();
            throw $e;
        }

        if ( $echo ) {
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }

}