<?php
namespace BooklyPaypalCheckout\Lib\Payment\Paypal;

class Order
{
    /** @var PurchaseUnit[] */
    protected $purchase_units;
    /** @var string */
    protected $return_url;
    /** @var string */
    protected $cancel_url;
    /** @var string */
    protected $brand_name;

    public function toJSON()
    {
        $purchase_units = array();
        foreach ( $this->purchase_units as $unit ) {
            $purchase_units[] = $unit->toArray();
        }

        return json_encode( array(
            'intent' => 'CAPTURE',
            'purchase_units' => $purchase_units,
            'application_context' => array(
                'brand_name' => $this->brand_name,
                'shipping_preference' => 'NO_SHIPPING',
                'user_action' => 'PAY_NOW',
                'return_url' => $this->return_url,
                'cancel_url' => $this->cancel_url,
            ),
        ) );
    }

    /**
     * Sets purchase_units
     *
     * @param PurchaseUnit $purchase_unit
     * @return $this
     */
    public function setPurchaseUnit( $purchase_unit )
    {
        $this->purchase_units = array( $purchase_unit );

        return $this;
    }

    /**
     * Sets return_url
     *
     * @param string $return_url
     * @return $this
     */
    public function setReturnUrl( $return_url )
    {
        $this->return_url = $return_url;

        return $this;
    }

    /**
     * Sets cancel_url
     *
     * @param string $cancel_url
     * @return $this
     */
    public function setCancelUrl( $cancel_url )
    {
        $this->cancel_url = $cancel_url;

        return $this;
    }

    /**
     * Sets brand_name
     *
     * @param string $brand_name
     * @return $this
     */
    public function setBrandName( $brand_name )
    {
        $this->brand_name = $brand_name;

        return $this;
    }

}