<?php
namespace BooklyPaypalCheckout\Lib\Payment\Paypal;

class Response
{
    /** @var array */
    public $data;

    /**
     * Response constructor.
     *
     * @param $response
     * @throws \Exception
     */
    public function __construct( $response )
    {
        if ( ! is_wp_error( $response ) && isset( $response['body'] ) ) {
            $this->data = json_decode( $response['body'], true );
            /* Headers
             * 200 ok
             * 201 created (order created)
             */
            if ( isset( $response['response']['code'] ) && $response['response']['code'] > 201 ) {
                $message = isset( $this->data['details'][0]['description'] )
                    ? $this->data['details'][0]['description']
                    : ( isset( $this->data['error_description'] ) ? $this->data['error_description'] : 'PayPal response error' );
                throw new \Exception( $message );
            }
        } else {
            /** @var \WP_Error $response */
            throw new \Exception( implode( PHP_EOL, $response->get_error_messages() ) );
        }
    }

    /**
     * @return string
     */
    public function getStatus()
    {
        return array_key_exists( 'status', $this->data )
            ? $this->data['status']
            : '';
    }

    /**
     * @return string
     */
    public function getError()
    {
        return array_key_exists( 'error_description', $this->data )
            ? $this->data['error_description']
            : '';
    }

    /**
     * @return string
     */
    public function getId()
    {
        return array_key_exists( 'id', $this->data )
            ? $this->data['id']
            : '';
    }
}